@@ -5,6 +5,8 @@
 
 from __future__ import annotations
 
+from . import time, zones
+
 from .explore import Action, Destination, Transition, State, Explorer
 from .time import TimeType, DiscreteTime
 from .values import Value
@@ -19,4 +21,6 @@ __all__ = [
     "TimeType",
     "DiscreteTime",
     "Value",
+    "time",
+    "zones",
 ]
